#
# Fedora spec file for php-goutte
#
# Copyright (c) 2014-2016 Shawn Iwinski <shawn@iwin.ski>
#
# License: MIT
# http://opensource.org/licenses/MIT
#
# Please preserve changelog entries
#

%global github_owner    FriendsOfPHP
%global github_name     Goutte
%global github_version  1.0.7
%global github_commit   794b196e76bdd37b5155cdecbad311f0a3b07625

%global composer_vendor  fabpot
%global composer_project goutte

# "php": ">=5.3.0"
%global php_min_ver 5.3.0
# "guzzle/http": "~3.1"
# "guzzle/plugin-history": "~3.1"
# "guzzle/plugin-mock": "~3.1"
#     NOTE: Min version not 3.1 because autoloader required
%global guzzle_min_ver 3.9.3
%global guzzle_max_ver 4.0
# "symfony/browser-kit": "~2.1"
# "symfony/css-selector": "~2.1"
# "symfony/dom-crawler": "~2.1"
# "symfony/finder": "~2.1"
# "symfony/process": "~2.1"
#     NOTE: Min version not 2.1 because autoloader required
%global symfony_min_ver %{?el6:2.3.31}%{!?el6:2.7.1}
%global symfony_max_ver 3.0

# Build using "--without tests" to disable tests
%global with_tests 0%{!?_without_tests:1}

%{!?phpdir:  %global phpdir  %{_datadir}/php}

Name:          php-goutte
Version:       %{github_version}
Release:       3%{?github_release}%{?dist}
Summary:       A simple PHP web scraper

Group:         Development/Libraries
License:       MIT
URL:           https://github.com/%{github_owner}/%{github_name}
Source0:       %{url}/archive/%{github_commit}/%{name}-%{github_version}-%{github_commit}.tar.gz

BuildArch:     noarch
# Library version value and autoloader check
BuildRequires: php-cli
# Tests
%if %{with_tests}
BuildRequires: php-composer(phpunit/phpunit)
%endif
## composer.json
BuildRequires: php(language)                       >= %{php_min_ver}
BuildRequires: php-composer(guzzle/http)           >= %{guzzle_min_ver}
BuildRequires: php-composer(guzzle/plugin-history) >= %{guzzle_min_ver}
BuildRequires: php-composer(guzzle/plugin-mock)    >= %{guzzle_min_ver}
BuildRequires: php-composer(symfony/browser-kit)   >= %{symfony_min_ver}
BuildRequires: php-composer(symfony/css-selector)  >= %{symfony_min_ver}
BuildRequires: php-composer(symfony/dom-crawler)   >= %{symfony_min_ver}
BuildRequires: php-composer(symfony/finder)        >= %{symfony_min_ver}
BuildRequires: php-composer(symfony/process)       >= %{symfony_min_ver}
BuildRequires: php-curl
## phpcompatinfo (computed from version 1.7.0)
# <none>
## Autoloader
BuildRequires: php-composer(symfony/class-loader)

# composer.json
Requires:      php(language)                      >= %{php_min_ver}
Requires:      php-composer(guzzle/http)          >= %{guzzle_min_ver}
Requires:      php-composer(guzzle/http)          <  %{guzzle_max_ver}
Requires:      php-composer(symfony/browser-kit)  >= %{symfony_min_ver}
Requires:      php-composer(symfony/browser-kit)  <  %{symfony_max_ver}
Requires:      php-composer(symfony/css-selector) >= %{symfony_min_ver}
Requires:      php-composer(symfony/css-selector) <  %{symfony_max_ver}
Requires:      php-composer(symfony/dom-crawler)  >= %{symfony_min_ver}
Requires:      php-composer(symfony/dom-crawler)  <  %{symfony_max_ver}
Requires:      php-composer(symfony/finder)       >= %{symfony_min_ver}
Requires:      php-composer(symfony/finder)       <  %{symfony_max_ver}
Requires:      php-composer(symfony/process)      >= %{symfony_min_ver}
Requires:      php-composer(symfony/process)      <  %{symfony_max_ver}
Requires:      php-curl
# phpcompatinfo (computed from version 1.7.0)
# <none>

# Standard "php-{COMPOSER_VENDOR}-{COMPOSER_PROJECT}" naming
Provides:      php-%{composer_vendor}-%{composer_project} = %{version}-%{release}
# Composer
Provides:      php-composer(%{composer_vendor}/%{composer_project}) = %{version}

%description
Goutte is a screen scraping and web crawling library for PHP.

Goutte provides a nice API to crawl websites and extract data
from the HTML/XML responses.

Autoloader: %{phpdir}/Goutte/autoload.php


%prep
%setup -qn %{github_name}-%{github_commit}

: Fix version
sed 's/0.2/%{version}/' -i Goutte/Client.php

: Create autoloader
cat <<'AUTOLOAD' | tee Goutte/autoload.php
<?php
/**
 * Autoloader for %{name} and its' dependencies
 * (created by %{name}-%{version}-%{release}).
 *
 * @return \Symfony\Component\ClassLoader\ClassLoader
 */

if (!isset($fedoraClassLoader) || !($fedoraClassLoader instanceof \Symfony\Component\ClassLoader\ClassLoader)) {
    if (!class_exists('Symfony\\Component\\ClassLoader\\ClassLoader', false)) {
        require_once '%{phpdir}/Symfony/Component/ClassLoader/ClassLoader.php';
    }

    $fedoraClassLoader = new \Symfony\Component\ClassLoader\ClassLoader();
    $fedoraClassLoader->register();
}

$fedoraClassLoader->addPrefix('Goutte\\', dirname(__DIR__));

require_once '%{phpdir}/Guzzle/autoload.php';
require_once '%{phpdir}/Symfony/Component/BrowserKit/autoload.php';
require_once '%{phpdir}/Symfony/Component/CssSelector/autoload.php';
require_once '%{phpdir}/Symfony/Component/DomCrawler/autoload.php';
require_once '%{phpdir}/Symfony/Component/Finder/autoload.php';
require_once '%{phpdir}/Symfony/Component/Process/autoload.php';

return $fedoraClassLoader;
AUTOLOAD


%build
# Empty build section, nothing required


%install
mkdir -p %{buildroot}/%{phpdir}/Goutte
cp -p Goutte/{autoload,Client}.php %{buildroot}/%{phpdir}/Goutte/


%check
: Library version value and autoloader check
%{_bindir}/php -r '
    require_once "%{buildroot}%{phpdir}/Goutte/autoload.php";
    $version = \Goutte\Client::VERSION;
    echo "Version $version (expected %{version})\n";
    exit(version_compare("%{version}", "$version", "=") ? 0 : 1);
'

%if %{with_tests}
: Run tests
%{_bindir}/phpunit --verbose \
    --bootstrap %{buildroot}/%{phpdir}/Goutte/autoload.php
%else
: Tests skipped
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc *.rst
%doc composer.json
%{phpdir}/Goutte


%changelog
* Mon Mar 28 2016 Shawn Iwinski <shawn@iwin.ski> - 1.0.7-3
- Fixed Guzzle min version for autoloader
- Added "php-{COMPOSER_VENDOR}-{COMPOSER_PROJECT}" virtual provide
- Fixed \Goutte\Client::VERSION
- Added library version value and autoloader check

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Nov 23 2015 Shawn Iwinski <shawn@iwin.ski> - 1.0.7-1
- Updated to 1.0.7
- Added spec file license header
- php-composer(*) dependencies
- Added php-composer(fabpot/goutte) virtual provide
- Added autoloader

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 16 2014 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.0.6-1
- Updated to 1.0.6

* Wed Feb 19 2014 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.0.5-1
- Updated to 1.0.5
- Conditional release dist
- Fixed %%files

* Mon Jan 27 2014 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.0.3-1.20140118gite83f8f9
- Initial package
